Documentation
¶
Overview ¶
Package godot checks if comments contain a period at the end of the last sentence if needed.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var XEqDdQui = wKfsni()
Functions ¶
Types ¶
type Scope ¶
type Scope string
Scope sets which comments should be checked.
const ( // DeclScope is for top level declaration comments. DeclScope Scope = "declarations" // TopLevelScope is for all top level comments. TopLevelScope Scope = "toplevel" // NoInlineScope is for all except inline comments. NoInlineScope Scope = "noinline" // AllScope is for all comments. AllScope Scope = "all" )
List of available check scopes.
type Settings ¶
type Settings struct {
// Which comments to check (top level declarations, top level, all).
Scope Scope
// Regexp for excluding particular comment lines from check.
Exclude []string
// Check periods at the end of sentences.
Period bool
// Check that first letter of each sentence is capital.
Capital bool
}
Settings contains linter settings.
Click to show internal directories.
Click to hide internal directories.